"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtPositioning import *


class QGeoRectangle(QGeoShape):
    """
    https://doc.qt.io/qt-6/qgeorectangle.html

    **Detailed Description**

    The rectangle is defined in terms of a **QGeoCoordinate**  which specifies
    the top left coordinate of the rectangle and a **QGeoCoordinate**  which
    specifies the bottom right coordinate of the rectangle.

    A geo rectangle is considered invalid if the top left or bottom right
    coordinates are invalid or if the top left coordinate is south of the bottom
    right coordinate.

    Geo rectangles can never cross the poles.

    Several methods behave as though the geo rectangle is defined in terms of a
    center coordinate, the width of the geo rectangle in degrees and the height
    of the geo rectangle in degrees.

    If the height or center of a geo rectangle is adjusted such that it would
    cross one of the poles the height is modified such that the geo rectangle
    touches but does not cross the pole and that the center coordinate is still
    in the center of the geo rectangle.

    This class is a **Q_GADGET**  since Qt 5.5. It can be **directly used from
    C++ and QML** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#QGeoRectangle

        **QGeoRectangle::QGeoRectangle()**

        Constructs a new, invalid geo rectangle.
        """
        ...

    @typing.overload
    def __init__(
        self, center: QGeoCoordinate, degreesWidth: float, degreesHeight: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#QGeoRectangle-1

        **QGeoRectangle::QGeoRectangle(const QGeoCoordinate & center , double
        degreesWidth , double degreesHeight )**

        Constructs a new geo rectangle centered at **center** with a width in
        degrees of **degreesWidth** and a height in degrees of
        **degreesHeight**.

        If **degreesHeight** would take the geo rectangle beyond one of the
        poles, the height of the geo rectangle will be truncated such that the
        geo rectangle only extends up to the pole. The center of the geo
        rectangle will be unchanged, and the height will be adjusted such that
        the center point is at the center of the truncated geo rectangle.
        """
        ...

    @typing.overload
    def __init__(self, topLeft: QGeoCoordinate, bottomRight: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#QGeoRectangle-2

        **QGeoRectangle::QGeoRectangle(const QGeoCoordinate & topLeft , const
        QGeoCoordinate & bottomRight )**

        Constructs a new geo rectangle with a top left coordinate **topLeft**
        and a bottom right coordinate **bottomRight**.
        """
        ...

    @typing.overload
    def __init__(self, coordinates: typing.Iterable[QGeoCoordinate]) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#QGeoRectangle-3

        **QGeoRectangle::QGeoRectangle(const QList<QGeoCoordinate> & coordinates
        )**

        Constructs a new geo rectangle, of minimum size, containing all of the
        **coordinates**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoRectangle") -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#QGeoRectangle-4

        **QGeoRectangle::QGeoRectangle(const QGeoRectangle & other )**

        Constructs a geo rectangle from the contents of **other**.
        """
        ...

    @typing.overload
    def __init__(self, other: QGeoShape) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#QGeoRectangle-5

        **QGeoRectangle::QGeoRectangle(const QGeoShape & other )**

        Constructs a geo rectangle from the contents of **other**.
        """
        ...

    def extendRectangle(self, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#extendRectangle

        **[invokable, since 5.9] void QGeoRectangle::extendRectangle(const
        QGeoCoordinate & coordinate )**

        Extends the geo rectangle to also cover the coordinate **coordinate**

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.9.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#toString

        **[invokable, since 5.5] QString QGeoRectangle::toString() const**

        Returns the geo rectangle properties as a string.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.5.
        """
        ...

    def united(self, rectangle: "QGeoRectangle") -> "QGeoRectangle":
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#united

        **[invokable] QGeoRectangle QGeoRectangle::united(const QGeoRectangle &
        rectangle ) const**

        Returns the smallest geo rectangle which contains both this geo
        rectangle and **rectangle**.

        If the centers of the two geo rectangles are separated by exactly 180.0
        degrees then the width is set to 360.0 degrees with the leftmost
        longitude set to -180.0 degrees and the rightmost longitude set to 180.0
        degrees. This is done to ensure that the result is independent of the
        order of the operands.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def translated(
        self, degreesLatitude: float, degreesLongitude: float
    ) -> "QGeoRectangle":
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#translated

        **[invokable] QGeoRectangle QGeoRectangle::translated(double
        degreesLatitude , double degreesLongitude ) const**

        Returns a copy of this geo rectangle translated by **degreesLatitude**
        northwards and **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        **See also** **translate** ().
        """
        ...

    def translate(self, degreesLatitude: float, degreesLongitude: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#translate

        **[invokable] void QGeoRectangle::translate(double degreesLatitude ,
        double degreesLongitude )**

        Translates this geo rectangle by **degreesLatitude** northwards and
        **degreesLongitude** eastwards.

        Negative values of **degreesLatitude** and **degreesLongitude**
        correspond to southward and westward translation respectively.

        If the translation would have caused the geo rectangle to cross a pole
        the geo rectangle will be translated until the top or bottom edge of the
        geo rectangle touches the pole but not further.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def intersects(self, rectangle: "QGeoRectangle") -> bool:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#intersects

        **[invokable] bool QGeoRectangle::intersects(const QGeoRectangle &
        rectangle ) const**

        Returns whether the geo rectangle **rectangle** intersects this geo
        rectangle.

        If the top or bottom edges of both geo rectangles are at one of the
        poles the geo rectangles are considered to be intersecting, since the
        longitude is irrelevant when the edges are at the pole.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def contains(self, rectangle: "QGeoRectangle") -> bool:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#contains

        **bool QGeoRectangle::contains(const QGeoRectangle & rectangle ) const**

        Returns whether the geo rectangle **rectangle** is contained within this
        geo rectangle.
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#height

        **double QGeoRectangle::height() const**

        Returns the height of this geo rectangle in degrees.

        The return value is undefined if this geo rectangle is invalid.

        **Note:** Getter function for property **height** .

        **See also** **setHeight** ().
        """
        ...

    def setHeight(self, degreesHeight: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setHeight

        **void QGeoRectangle::setHeight(double degreesHeight )**

        Sets the height of this geo rectangle in degrees to **degreesHeight**.

        **Note:** Setter function for property **height** .

        **See also** **height** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#width

        **double QGeoRectangle::width() const**

        Returns the width of this geo rectangle in degrees.

        The return value is undefined if this geo rectangle is invalid.

        **Note:** Getter function for property **width** .

        **See also** **setWidth** ().
        """
        ...

    def setWidth(self, degreesWidth: float) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setWidth

        **void QGeoRectangle::setWidth(double degreesWidth )**

        Sets the width of this geo rectangle in degrees to **degreesWidth**.

        **Note:** Setter function for property **width** .

        **See also** **width** ().
        """
        ...

    def center(self) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#center

        **QGeoCoordinate QGeoRectangle::center() const**

        Returns the center of this geo rectangle. Equivalent to
        **QGeoShape::center** ().

        **Note:** Getter function for property **center** .

        **See also** **setCenter** ().
        """
        ...

    def setCenter(self, center: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setCenter

        **void QGeoRectangle::setCenter(const QGeoCoordinate & center )**

        Sets the center of this geo rectangle to **center**.

        If this causes the geo rectangle to cross on of the poles the height of
        the geo rectangle will be truncated such that the geo rectangle only
        extends up to the pole. The center of the geo rectangle will be
        unchanged, and the height will be adjusted such that the center point is
        at the center of the truncated geo rectangle.

        **Note:** Setter function for property **center** .

        **See also** **center** ().
        """
        ...

    def bottomRight(self) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#bottomRight

        **QGeoCoordinate QGeoRectangle::bottomRight() const**

        Returns the bottom right coordinate of this geo rectangle.

        **Note:** Getter function for property **bottomRight** .

        **See also** **setBottomRight** ().
        """
        ...

    def setBottomRight(self, bottomRight: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setBottomRight

        **void QGeoRectangle::setBottomRight(const QGeoCoordinate & bottomRight
        )**

        Sets the bottom right coordinate of this geo rectangle to
        **bottomRight**.

        **Note:** Setter function for property **bottomRight** .

        **See also** **bottomRight** ().
        """
        ...

    def bottomLeft(self) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#bottomLeft

        **QGeoCoordinate QGeoRectangle::bottomLeft() const**

        Returns the bottom left coordinate of this geo rectangle.

        **Note:** Getter function for property **bottomLeft** .

        **See also** **setBottomLeft** ().
        """
        ...

    def setBottomLeft(self, bottomLeft: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setBottomLeft

        **void QGeoRectangle::setBottomLeft(const QGeoCoordinate & bottomLeft
        )**

        Sets the bottom left coordinate of this geo rectangle to **bottomLeft**.

        **Note:** Setter function for property **bottomLeft** .

        **See also** **bottomLeft** ().
        """
        ...

    def topRight(self) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#topRight

        **QGeoCoordinate QGeoRectangle::topRight() const**

        Returns the top right coordinate of this geo rectangle.

        **Note:** Getter function for property **topRight** .

        **See also** **setTopRight** ().
        """
        ...

    def setTopRight(self, topRight: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setTopRight

        **void QGeoRectangle::setTopRight(const QGeoCoordinate & topRight )**

        Sets the top right coordinate of this geo rectangle to **topRight**.

        **Note:** Setter function for property **topRight** .

        **See also** **topRight** ().
        """
        ...

    def topLeft(self) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#topLeft

        **QGeoCoordinate QGeoRectangle::topLeft() const**

        Returns the top left coordinate of this geo rectangle.

        **Note:** Getter function for property **topLeft** .

        **See also** **setTopLeft** ().
        """
        ...

    def setTopLeft(self, topLeft: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeorectangle.html#setTopLeft

        **void QGeoRectangle::setTopLeft(const QGeoCoordinate & topLeft )**

        Sets the top left coordinate of this geo rectangle to **topLeft**.

        **Note:** Setter function for property **topLeft** .

        **See also** **topLeft** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtSql import *


class QSqlIndex(QSqlRecord):
    """
    https://doc.qt.io/qt-6/qsqlindex.html

    **Detailed Description**

    An **index** refers to a single table or view in a database. Information
    about the fields that comprise the index can be used to generate SQL
    statements.
    """

    @typing.overload
    def __init__(self, cursorName: str = ..., name: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#QSqlIndex

        **QSqlIndex::QSqlIndex(const QString & cursorname = QString(), const
        QString & name = QString())**

        Constructs an empty index using the cursor name **cursorname** and index
        name **name**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSqlIndex") -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#QSqlIndex-1

        **QSqlIndex::QSqlIndex(const QSqlIndex & other )**

        Constructs a copy of **other**.
        """
        ...

    def setDescending(self, i: int, desc: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#setDescending

        **void QSqlIndex::setDescending(int i , bool desc )**

        If **desc** is true, field **i** is sorted in descending order.
        Otherwise, field **i** is sorted in ascending order (the default). If
        the field does not exist, nothing happens.

        **See also** **isDescending** ().
        """
        ...

    def isDescending(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#isDescending

        **bool QSqlIndex::isDescending(int i ) const**

        Returns `true` if field **i** in the index is sorted in descending
        order; otherwise returns `false`.
        """
        ...

    @typing.overload
    def append(self, field: QSqlField) -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#append

        **void QSqlIndex::append(const QSqlField & field )**

        Appends the field **field** to the list of indexed fields. The field is
        appended with an ascending sort order.
        """
        ...

    @typing.overload
    def append(self, field: QSqlField, desc: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#append-1

        **void QSqlIndex::append(const QSqlField & field , bool desc )**

        This is an overloaded function.

        Appends the field **field** to the list of indexed fields. The field is
        appended with an ascending sort order, unless **desc** is true.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#name

        **QString QSqlIndex::name() const**

        Returns the name of the index.

        **See also** **setName** ().
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#setName

        **void QSqlIndex::setName(const QString & name )**

        Sets the name of the index to **name**.

        **See also** **name** ().
        """
        ...

    def cursorName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#cursorName

        **QString QSqlIndex::cursorName() const**

        Returns the name of the cursor which the index is associated with.

        **See also** **setCursorName** ().
        """
        ...

    def setCursorName(self, cursorName: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlindex.html#setCursorName

        **void QSqlIndex::setCursorName(const QString & cursorName )**

        Sets the name of the cursor that the index is associated with to
        **cursorName**.

        **See also** **cursorName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneWheelEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html

    **Detailed Description**

    **QWheelEvent** s received by a **QGraphicsView**  are translated into
    QGraphicsSceneWheelEvents; it translates the QWheelEvent::globalPos() into
    item, scene, and screen coordinates (**pos** (), **scenePos** (), and
    **screenPos** ()).

    **See also** **QGraphicsSceneMouseEvent** ,
    **QGraphicsSceneContextMenuEvent** , **QGraphicsSceneHoverEvent** , and
    **QWheelEvent** .
    """

    def isInverted(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#isInverted

        **[since 6.2] bool QGraphicsSceneWheelEvent::isInverted() const**

        Returns whether the delta values delivered with the event are inverted.

        This function was introduced in Qt 6.2.
        """
        ...

    def pixelDelta(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#pixelDelta

        **[since 6.2] QPoint QGraphicsSceneWheelEvent::pixelDelta() const**

        Returns the scrolling distance in pixels on screen. This value is
        provided on platforms that support high-resolution pixel-based delta
        values, such as macOS. The value should be used directly to scroll
        content on screen.

        This function was introduced in Qt 6.2.

        **See also** **QWheelEvent::pixelDelta** .
        """
        ...

    def phase(self) -> QtCore.Qt.ScrollPhase:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#phase

        **[since 6.2] Qt::ScrollPhase QGraphicsSceneWheelEvent::phase() const**

        Returns the scrolling phase of this wheel event.

        This function was introduced in Qt 6.2.

        **See also** **QWheelEvent::phase** .
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#orientation

        **Qt::Orientation QGraphicsSceneWheelEvent::orientation() const**

        Returns the wheel orientation.
        """
        ...

    def delta(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#delta

        **int QGraphicsSceneWheelEvent::delta() const**

        Returns the distance that the wheel is rotated, in eighths (1/8s) of a
        degree. A positive value indicates that the wheel was rotated forwards
        away from the user; a negative value indicates that the wheel was
        rotated backwards toward the user.

        Most mouse types work in steps of 15 degrees, in which case the delta
        value is a multiple of 120 (== 15 * 8).
        """
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#modifiers

        **Qt::KeyboardModifiers QGraphicsSceneWheelEvent::modifiers() const**

        Returns the keyboard modifiers that were active when the wheel event
        occurred.

        **See also** **buttons** ().
        """
        ...

    def buttons(self) -> QtCore.Qt.MouseButton:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#buttons

        **Qt::MouseButtons QGraphicsSceneWheelEvent::buttons() const**

        Returns the mouse buttons that were pressed when the wheel event
        occurred.

        **See also** **modifiers** ().
        """
        ...

    def screenPos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#screenPos

        **QPoint QGraphicsSceneWheelEvent::screenPos() const**

        Returns the position of the cursor in screen coordinates when the wheel
        event occurred.

        **See also** **pos** () and **scenePos** ().
        """
        ...

    def scenePos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#scenePos

        **QPointF QGraphicsSceneWheelEvent::scenePos() const**

        Returns the position of the cursor in scene coordinates when the wheel
        event occurred.

        **See also** **pos** () and **screenPos** ().
        """
        ...

    def pos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenewheelevent.html#pos

        **QPointF QGraphicsSceneWheelEvent::pos() const**

        Returns the position of the cursor in item coordinates when the wheel
        event occurred.

        **See also** **scenePos** () and **screenPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QQuaternion(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qquaternion.html

    **Detailed Description**

    Quaternions are used to represent rotations in 3D space, and consist of a 3D
    rotation axis specified by the x, y, and z coordinates, and a scalar
    representing the rotation angle.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#QQuaternion

        **QQuaternion::QQuaternion()**

        Constructs an identity quaternion (1, 0, 0, 0), i.e. with the vector (0,
        0, 0) and scalar 1.
        """
        ...

    @typing.overload
    def __init__(self, aScalar: float, xpos: float, ypos: float, zpos: float) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#QQuaternion-2

        **QQuaternion::QQuaternion(float scalar , float xpos , float ypos ,
        float zpos )**

        Constructs a quaternion with the vector ( **xpos** , **ypos** , **zpos**
        ) and **scalar**.
        """
        ...

    @typing.overload
    def __init__(self, aScalar: float, aVector: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#QQuaternion-3

        **QQuaternion::QQuaternion(float scalar , const QVector3D & vector )**

        Constructs a quaternion vector from the specified **vector** and
        **scalar**.

        **See also** **vector** () and **scalar** ().
        """
        ...

    @typing.overload
    def __init__(self, aVector: "QVector4D") -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#QQuaternion-4

        **QQuaternion::QQuaternion(const QVector4D & vector )**

        Constructs a quaternion from the components of **vector**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQuaternion") -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#QQuaternion

        **QQuaternion::QQuaternion()**

        Constructs an identity quaternion (1, 0, 0, 0), i.e. with the vector (0,
        0, 0) and scalar 1.
        """
        ...

    def __neg__(self) -> "QQuaternion":
        ...

    def toEulerAngles(self) -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qquaternion.html#toEulerAngles

        **[since 5.5] QVector3D QQuaternion::toEulerAngles() const**

        This is an overloaded function.

        Calculates roll, pitch, and yaw Euler angles (in degrees) that
        corresponds to this quaternion.

        This function was introduced in Qt 5.5.

        **See also** **fromEulerAngles** ().
        """
        ...

    def conjugated(self) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#conjugated

        **[since 5.5] QQuaternion QQuaternion::conjugated() const**

        Returns the conjugate of this quaternion, which is (-x, -y, -z, scalar).

        This function was introduced in Qt 5.5.
        """
        ...

    def inverted(self) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#inverted

        **[since 5.5] QQuaternion QQuaternion::inverted() const**

        Returns the inverse of this quaternion. If this quaternion is null, then
        a null quaternion is returned.

        This function was introduced in Qt 5.5.

        **See also** **isNull** () and **length** ().
        """
        ...

    @staticmethod
    def dotProduct(q1: "QQuaternion", q2: "QQuaternion") -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#dotProduct

        **[static, since 5.5] float QQuaternion::dotProduct(const QQuaternion &
        q1 , const QQuaternion & q2 )**

        Returns the dot product of **q1** and **q2**.

        This function was introduced in Qt 5.5.

        **See also** **length** ().
        """
        ...

    @staticmethod
    def rotationTo(from_: "QVector3D", to: "QVector3D") -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#rotationTo

        **[static, since 5.5] QQuaternion QQuaternion::rotationTo(const
        QVector3D & from , const QVector3D & to )**

        Returns the shortest arc quaternion to rotate from the direction
        described by the vector **from** to the direction described by the
        vector **to**.

        This function was introduced in Qt 5.5.

        **See also** **fromDirection** ().
        """
        ...

    @staticmethod
    def fromDirection(direction: "QVector3D", up: "QVector3D") -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromDirection

        **[static, since 5.5] QQuaternion QQuaternion::fromDirection(const
        QVector3D & direction , const QVector3D & up )**

        Constructs the quaternion using specified forward direction
        **direction** and upward direction **up**. If the upward direction was
        not specified or the forward and upward vectors are collinear, a new
        orthonormal upward direction will be generated.

        This function was introduced in Qt 5.5.

        **See also** **fromAxes** () and **rotationTo** ().
        """
        ...

    @staticmethod
    def fromAxes(
        xAxis: "QVector3D", yAxis: "QVector3D", zAxis: "QVector3D"
    ) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromAxes

        **[static, since 5.5] QQuaternion QQuaternion::fromAxes(const QVector3D
        & xAxis , const QVector3D & yAxis , const QVector3D & zAxis )**

        Constructs the quaternion using 3 axes ( **xAxis** , **yAxis** ,
        **zAxis** ).

        **Note:** The axes are assumed to be orthonormal.

        This function was introduced in Qt 5.5.

        **See also** **getAxes** () and **fromRotationMatrix** ().
        """
        ...

    def getAxes(self) -> typing.Tuple["QVector3D", "QVector3D", "QVector3D"]:
        """
        https://doc.qt.io/qt-6/qquaternion.html#getAxes

        **[since 5.5] void QQuaternion::getAxes(QVector3D * xAxis , QVector3D *
        yAxis , QVector3D * zAxis ) const**

        Returns the 3 orthonormal axes ( **xAxis** , **yAxis** , **zAxis** )
        defining the quaternion.

        This function was introduced in Qt 5.5.

        **See also** **fromAxes** () and **toRotationMatrix** ().
        """
        ...

    @staticmethod
    def fromRotationMatrix(rot3x3: QMatrix3x3) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromRotationMatrix

        **[static, since 5.5] QQuaternion QQuaternion::fromRotationMatrix(const
        QMatrix3x3 & rot3x3 )**

        Creates a quaternion that corresponds to a rotation matrix **rot3x3**.

        **Note:** If a given rotation matrix is not normalized, the resulting
        quaternion will contain scaling information.

        This function was introduced in Qt 5.5.

        **See also** **toRotationMatrix** () and **fromAxes** ().
        """
        ...

    def toRotationMatrix(self) -> QMatrix3x3:
        """
        https://doc.qt.io/qt-6/qquaternion.html#toRotationMatrix

        **[since 5.5] QMatrix3x3 QQuaternion::toRotationMatrix() const**

        Creates a rotation matrix that corresponds to this quaternion.

        **Note:** If this quaternion is not normalized, the resulting rotation
        matrix will contain scaling information.

        This function was introduced in Qt 5.5.

        **See also** **fromRotationMatrix** () and **getAxes** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromEulerAngles(pitch: float, yaw: float, roll: float) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromEulerAngles

        **[static, since 5.5] QQuaternion QQuaternion::fromEulerAngles(float
        pitch , float yaw , float roll )**

        Creates a quaternion that corresponds to a rotation of **roll** degrees
        around the z axis, **pitch** degrees around the x axis, and **yaw**
        degrees around the y axis (in that order).

        This function was introduced in Qt 5.5.

        **See also** **getEulerAngles** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromEulerAngles(eulerAngles: "QVector3D") -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromEulerAngles-1

        **[static, since 5.5] QQuaternion QQuaternion::fromEulerAngles(const
        QVector3D & eulerAngles )**

        This is an overloaded function.

        Creates a quaternion that corresponds to a rotation of **eulerAngles** :
        eulerAngles.**z** () degrees around the z axis, eulerAngles.**x** ()
        degrees around the x axis, and eulerAngles.**y** () degrees around the y
        axis (in that order).

        This function was introduced in Qt 5.5.

        **See also** **toEulerAngles** ().
        """
        ...

    def getEulerAngles(self) -> typing.Tuple[float, float, float]:
        """
        https://doc.qt.io/qt-6/qquaternion.html#getEulerAngles

        **[since 5.5] void QQuaternion::getEulerAngles(float * pitch , float *
        yaw , float * roll ) const**

        Calculates **roll** , **pitch** , and **yaw** Euler angles (in degrees)
        that corresponds to this quaternion.

        This function was introduced in Qt 5.5.

        **See also** **fromEulerAngles** ().
        """
        ...

    def getAxisAndAngle(self) -> typing.Tuple["QVector3D", float]:
        """
        https://doc.qt.io/qt-6/qquaternion.html#getAxisAndAngle

        **[since 5.5] void QQuaternion::getAxisAndAngle(float * x , float * y ,
        float * z , float * angle ) const**

        Extracts a 3D axis ( **x** , **y** , **z** ) and a rotating angle
        **angle** (in degrees) that corresponds to this quaternion.

        This function was introduced in Qt 5.5.

        **See also** **fromAxisAndAngle** ().
        """
        ...

    def toVector4D(self) -> "QVector4D":
        """
        https://doc.qt.io/qt-6/qquaternion.html#toVector4D

        **QVector4D QQuaternion::toVector4D() const**

        Returns this quaternion as a 4D vector.
        """
        ...

    def vector(self) -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qquaternion.html#vector

        **QVector3D QQuaternion::vector() const**

        Returns the vector component of this quaternion.

        **See also** **setVector** () and **scalar** ().
        """
        ...

    @typing.overload
    def setVector(self, aVector: "QVector3D") -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#setVector

        **void QQuaternion::setVector(const QVector3D & vector )**

        Sets the vector component of this quaternion to **vector**.

        **See also** **vector** () and **setScalar** ().
        """
        ...

    @typing.overload
    def setVector(self, aX: float, aY: float, aZ: float) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#setVector-1

        **void QQuaternion::setVector(float x , float y , float z )**

        Sets the vector component of this quaternion to ( **x** , **y** , **z**
        ).

        **See also** **vector** () and **setScalar** ().
        """
        ...

    def setScalar(self, aScalar: float) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#setScalar

        **void QQuaternion::setScalar(float scalar )**

        Sets the scalar component of this quaternion to **scalar**.

        **See also** **scalar** (), **setX** (), **setY** (), and **setZ** ().
        """
        ...

    def setZ(self, aZ: float) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#setZ

        **void QQuaternion::setZ(float z )**

        Sets the z coordinate of this quaternion's vector to the given **z**
        coordinate.

        **See also** **z** (), **setX** (), **setY** (), and **setScalar** ().
        """
        ...

    def setY(self, aY: float) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#setY

        **void QQuaternion::setY(float y )**

        Sets the y coordinate of this quaternion's vector to the given **y**
        coordinate.

        **See also** **y** (), **setX** (), **setZ** (), and **setScalar** ().
        """
        ...

    def setX(self, aX: float) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#setX

        **void QQuaternion::setX(float x )**

        Sets the x coordinate of this quaternion's vector to the given **x**
        coordinate.

        **See also** **x** (), **setY** (), **setZ** (), and **setScalar** ().
        """
        ...

    def scalar(self) -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#scalar

        **float QQuaternion::scalar() const**

        Returns the scalar component of this quaternion.

        **See also** **setScalar** (), **x** (), **y** (), and **z** ().
        """
        ...

    def z(self) -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#z

        **float QQuaternion::z() const**

        Returns the z coordinate of this quaternion's vector.

        **See also** **setZ** (), **x** (), **y** (), and **scalar** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#y

        **float QQuaternion::y() const**

        Returns the y coordinate of this quaternion's vector.

        **See also** **setY** (), **x** (), **z** (), and **scalar** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#x

        **float QQuaternion::x() const**

        Returns the x coordinate of this quaternion's vector.

        **See also** **setX** (), **y** (), **z** (), and **scalar** ().
        """
        ...

    def isIdentity(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquaternion.html#isIdentity

        **bool QQuaternion::isIdentity() const**

        Returns `true` if the x, y, and z components of this quaternion are set
        to 0.0, and the scalar component is set to 1.0; otherwise returns
        `false`.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquaternion.html#isNull

        **bool QQuaternion::isNull() const**

        Returns `true` if the x, y, z, and scalar components of this quaternion
        are set to 0.0; otherwise returns `false`.
        """
        ...

    @staticmethod
    def nlerp(q1: "QQuaternion", q2: "QQuaternion", t: float) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#nlerp

        **[static] QQuaternion QQuaternion::nlerp(const QQuaternion & q1 , const
        QQuaternion & q2 , float t )**

        Interpolates along the shortest linear path between the rotational
        positions **q1** and **q2**. The value **t** should be between 0 and 1,
        indicating the distance to travel between **q1** and **q2**. The result
        will be **normalized** ().

        If **t** is less than or equal to 0, then **q1** will be returned. If
        **t** is greater than or equal to 1, then **q2** will be returned.

        The nlerp() function is typically faster than **slerp** () and will give
        approximate results to spherical interpolation that are good enough for
        some applications.

        **See also** **slerp** ().
        """
        ...

    @staticmethod
    def slerp(q1: "QQuaternion", q2: "QQuaternion", t: float) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#slerp

        **[static] QQuaternion QQuaternion::slerp(const QQuaternion & q1 , const
        QQuaternion & q2 , float t )**

        Interpolates along the shortest spherical path between the rotational
        positions **q1** and **q2**. The value **t** should be between 0 and 1,
        indicating the spherical distance to travel between **q1** and **q2**.

        If **t** is less than or equal to 0, then **q1** will be returned. If
        **t** is greater than or equal to 1, then **q2** will be returned.

        **See also** **nlerp** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromAxisAndAngle(axis: "QVector3D", angle: float) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromAxisAndAngle

        **[static] QQuaternion QQuaternion::fromAxisAndAngle(const QVector3D &
        axis , float angle )**

        Creates a normalized quaternion that corresponds to rotating through
        **angle** degrees about the specified 3D **axis**.

        **See also** **getAxisAndAngle** ().
        """
        ...

    @typing.overload
    @staticmethod
    def fromAxisAndAngle(x: float, y: float, z: float, angle: float) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#fromAxisAndAngle-1

        **[static] QQuaternion QQuaternion::fromAxisAndAngle(float x , float y ,
        float z , float angle )**

        Creates a normalized quaternion that corresponds to rotating through
        **angle** degrees about the 3D axis ( **x** , **y** , **z** ).

        **See also** **getAxisAndAngle** ().
        """
        ...

    def rotatedVector(self, vector: "QVector3D") -> "QVector3D":
        """
        https://doc.qt.io/qt-6/qquaternion.html#rotatedVector

        **QVector3D QQuaternion::rotatedVector(const QVector3D & vector )
        const**

        Rotates **vector** with this quaternion to produce a new vector in 3D
        space. The following code:

        QVector3D result = q.rotatedVector(vector);

        is equivalent to the following:

        QVector3D result = (q * **QQuaternion** (0, vector) *
        q.conjugated()).vector();
        """
        ...

    def normalize(self) -> None:
        """
        https://doc.qt.io/qt-6/qquaternion.html#normalize

        **void QQuaternion::normalize()**

        Normalizes the current quaternion in place. Nothing happens if this is a
        null quaternion or the length of the quaternion is very close to 1.

        **See also** **length** () and **normalized** ().
        """
        ...

    def normalized(self) -> "QQuaternion":
        """
        https://doc.qt.io/qt-6/qquaternion.html#normalized

        **QQuaternion QQuaternion::normalized() const**

        Returns the normalized unit form of this quaternion.

        If this quaternion is null, then a null quaternion is returned. If the
        length of the quaternion is very close to 1, then the quaternion will be
        returned as-is. Otherwise the normalized form of the quaternion of
        length 1 will be returned.

        **See also** **normalize** (), **length** (), and **dotProduct** ().
        """
        ...

    def lengthSquared(self) -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#lengthSquared

        **float QQuaternion::lengthSquared() const**

        Returns the squared length of the quaternion.

        **Note:** Though cheap to compute, this is susceptible to overflow and
        underflow that **length** () avoids in many cases.

        **See also** **length** () and **dotProduct** ().
        """
        ...

    def length(self) -> float:
        """
        https://doc.qt.io/qt-6/qquaternion.html#length

        **float QQuaternion::length() const**

        Returns the length of the quaternion. This is also called the "norm".

        **See also** **lengthSquared** (), **normalized** (), and **dotProduct**
        ().
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *
import enum


class QMediaRecorder(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qmediarecorder.html

    **Detailed Description**

    The QMediaRecorder class is a class for encoding and recording media
    generated in a **QMediaCaptureSession** .

    **QMediaCaptureSession**  session;
        **QAudioInput**  audioInput;
    session.setAudioInput(&input);
        **QMediaRecorder**  recorder;
    session.setMediaRecorder(&recorder);
    recorder.setQuality(**QMediaRecorder** ::HighQuality);
    recorder.setOutputLocation(**QUrl** ::fromLocalFile("test.mp3"));
    recorder.record();
    """

    class Error(enum.Enum):
        NoError: QMediaRecorder = ...
        ResourceError: QMediaRecorder = ...
        FormatError: QMediaRecorder = ...
        OutOfSpaceError: QMediaRecorder = ...
        LocationNotWritable: QMediaRecorder = ...

    class RecorderState(enum.Enum):
        StoppedState: QMediaRecorder = ...
        RecordingState: QMediaRecorder = ...
        PausedState: QMediaRecorder = ...

    class EncodingMode(enum.Enum):
        ConstantQualityEncoding: QMediaRecorder = ...
        ConstantBitRateEncoding: QMediaRecorder = ...
        AverageBitRateEncoding: QMediaRecorder = ...
        TwoPassEncoding: QMediaRecorder = ...

    class Quality(enum.Enum):
        VeryLowQuality: QMediaRecorder = ...
        LowQuality: QMediaRecorder = ...
        NormalQuality: QMediaRecorder = ...
        HighQuality: QMediaRecorder = ...
        VeryHighQuality: QMediaRecorder = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#QMediaRecorder

        **QMediaRecorder::QMediaRecorder(QObject * parent = nullptr)**

        Constructs a media recorder which records the media produced by a
        microphone and camera. The media recorder is a child of **parent**.
        """
        ...

    def audioSampleRateChanged(self) -> None:
        ...

    def audioChannelCountChanged(self) -> None:
        ...

    def audioBitRateChanged(self) -> None:
        ...

    def videoBitRateChanged(self) -> None:
        ...

    def videoFrameRateChanged(self) -> None:
        ...

    def videoResolutionChanged(self) -> None:
        ...

    def qualityChanged(self) -> None:
        ...

    def encodingModeChanged(self) -> None:
        ...

    def errorChanged(self) -> None:
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#stop

        **[slot] void QMediaRecorder::stop()**

        Stops recording.

        The recorder state is changed to **QMediaRecorder::StoppedState** .
        """
        ...

    def pause(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#pause

        **[slot] void QMediaRecorder::pause()**

        Pauses recording.

        The recorder state is changed to **QMediaRecorder::PausedState** .

        Depending on the platform, pausing recording may be not supported. In
        this case the recorder state is unchanged.
        """
        ...

    def record(self) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#record

        **[slot] void QMediaRecorder::record()**

        Start recording.

        While the recorder state is changed immediately to
        c{**QMediaRecorder::RecordingState** }, recording may start
        asynchronously.

        If recording fails **error** () signal is emitted with recorder state
        being reset back to `QMediaRecorder::StoppedState`.

        **Note:** On mobile devices, recording will happen in the orientation
        the device had when calling record and is locked for the duration of the
        recording. To avoid artifacts on the user interface, we recommend to
        keep the user interface locked to the same orientation as long as the
        recording is ongoing using the contentOrientation property of
        **QWindow**  and unlock it again once the recording is finished.
        """
        ...

    def captureSession(self) -> QMediaCaptureSession:
        ...

    def setMetaData(self, metaData: QMediaMetaData) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setMetaData

        **void QMediaRecorder::setMetaData(const QMediaMetaData & metaData )**

        Sets the meta data to **metaData**.

        **Note:** To ensure that meta-data is set correctly, it should be set
        before starting the recording. Once the recording is started, any meta-
        data set will be attached to the next recording.

        **Note:** Setter function for property **metaData** .

        **See also** **metaData** ().
        """
        ...

    def metaData(self) -> QMediaMetaData:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#metaData

        **QMediaMetaData QMediaRecorder::metaData() const**

        Returns the metaData associated with the recording.

        **Note:** Getter function for property metaData.

        **See also** **setMetaData** ().
        """
        ...

    def setAudioSampleRate(self, sampleRate: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setAudioSampleRate

        **void QMediaRecorder::setAudioSampleRate(int sampleRate )**

        Sets the audio **sampleRate** in Hz.

        A value of `-1` indicates the recorder should make an optimal choice
        based on what is available from the audio source, and the limitations of
        the codec.

        **See also** **audioSampleRate** ().
        """
        ...

    def audioSampleRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#audioSampleRate

        **int QMediaRecorder::audioSampleRate() const**

        Returns the audio sample rate in Hz.

        **See also** **setAudioSampleRate** ().
        """
        ...

    def setAudioChannelCount(self, channels: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setAudioChannelCount

        **void QMediaRecorder::setAudioChannelCount(int channels )**

        Sets the number of audio **channels**.

        A value of -1 indicates the recorder should make an optimal choice based
        on what is available from the audio source and the limitations of the
        codec.

        **See also** **audioChannelCount** ().
        """
        ...

    def audioChannelCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#audioChannelCount

        **int QMediaRecorder::audioChannelCount() const**

        Returns the number of audio channels.

        **See also** **setAudioChannelCount** ().
        """
        ...

    def setAudioBitRate(self, bitRate: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setAudioBitRate

        **void QMediaRecorder::setAudioBitRate(int bitRate )**

        Sets the audio **bitRate** in bits per second.

        **See also** **audioBitRate** ().
        """
        ...

    def audioBitRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#audioBitRate

        **int QMediaRecorder::audioBitRate() const**

        Returns the bit rate of the compressed audio stream in bits per second.

        **See also** **setAudioBitRate** ().
        """
        ...

    def setVideoBitRate(self, bitRate: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setVideoBitRate

        **void QMediaRecorder::setVideoBitRate(int bitRate )**

        Sets the video **bitRate** in bits per second.

        **See also** **videoBitRate** ().
        """
        ...

    def videoBitRate(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#videoBitRate

        **int QMediaRecorder::videoBitRate() const**

        Returns the bit rate of the compressed video stream in bits per second.

        **See also** **setVideoBitRate** ().
        """
        ...

    def setVideoFrameRate(self, frameRate: float) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setVideoFrameRate

        **void QMediaRecorder::setVideoFrameRate(qreal frameRate )**

        Sets the video **frameRate**.

        A value of 0 indicates the recorder should make an optimal choice based
        on what is available from the video source and the limitations of the
        codec.

        **See also** **videoFrameRate** ().
        """
        ...

    def videoFrameRate(self) -> float:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#videoFrameRate

        **qreal QMediaRecorder::videoFrameRate() const**

        Returns the video frame rate.

        **See also** **setVideoFrameRate** ().
        """
        ...

    @typing.overload
    def setVideoResolution(self, a0: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setVideoResolution

        **void QMediaRecorder::setVideoResolution(const QSize & size )**

        Sets the resolution of the encoded video to **size**.

        Pass an empty **QSize**  to make the recorder choose an optimal
        resolution based on what is available from the video source and the
        limitations of the codec.

        **See also** **videoResolution** ().
        """
        ...

    @typing.overload
    def setVideoResolution(self, width: int, height: int) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setVideoResolution-1

        **void QMediaRecorder::setVideoResolution(int width , int height )**

        Sets the **width** and **height** of the resolution of the encoded
        video.

        This is an overloaded function.
        """
        ...

    def videoResolution(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#videoResolution

        **QSize QMediaRecorder::videoResolution() const**

        Returns the resolution of the encoded video.

        **See also** **setVideoResolution** ().
        """
        ...

    def setQuality(self, quality: "QMediaRecorder.Quality") -> None:
        ...

    def quality(self) -> "QMediaRecorder.Quality":
        ...

    def setEncodingMode(self, a0: "QMediaRecorder.EncodingMode") -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#setEncodingMode

        **void QMediaRecorder::setEncodingMode(QMediaRecorder::EncodingMode mode
        )**

        Sets the encoding **mode** setting.

        If **ConstantQualityEncoding**  is set, the quality encoding parameter
        is used and bit rates are ignored, otherwise the bitrates are used.

        **See also** **encodingMode** () and **EncodingMode** .
        """
        ...

    def encodingMode(self) -> "QMediaRecorder.EncodingMode":
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#encodingMode

        **QMediaRecorder::EncodingMode QMediaRecorder::encodingMode() const**

        Returns the encoding mode.

        **See also** **setEncodingMode** () and **EncodingMode** .
        """
        ...

    def setMediaFormat(self, format: QMediaFormat) -> None:
        ...

    def mediaFormat(self) -> QMediaFormat:
        ...

    def duration(self) -> int:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#duration-prop

        **[read-only] duration : const qint64**

        This property holds the recorded media duration in milliseconds.

        **Access functions:**

        qint64 **duration** () const

        **Notifier signal:**

        void ****durationChanged** ** (qint64 **duration** )
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#errorString

        **QString QMediaRecorder::errorString() const**

        Returns a string describing the current error state.

        **Note:** Getter function for property errorString.

        **See also** **error** ().
        """
        ...

    def error(self) -> "QMediaRecorder.Error":
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#error

        **QMediaRecorder::Error QMediaRecorder::error() const**

        Returns the current error state.

        **Note:** Getter function for property error.

        **See also** **errorString** ().
        """
        ...

    def recorderState(self) -> "QMediaRecorder.RecorderState":
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#recorderState

        **QMediaRecorder::RecorderState QMediaRecorder::recorderState() const**

        Returns the current media recorder state.

        **Note:** Getter function for property recorderState.

        **See also** **QMediaRecorder::RecorderState** .
        """
        ...

    def actualLocation(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#actualLocation-prop

        **[read-only] actualLocation : const QUrl**

        This property holds the actual location of the last media content.

        The actual location is usually available after recording starts, and
        reset when new location is set or new recording starts.

        **Access functions:**

        QUrl **actualLocation** () const

        **Notifier signal:**

        void ****actualLocationChanged** ** (const QUrl & **location** )
        """
        ...

    def setOutputLocation(self, location: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#outputLocation-prop

        **outputLocation : QUrl**

        This property holds the destination location of media content.

        Setting the location can fail, for example when the service supports
        only local file system locations but a network URL was passed. If the
        operation fails an errorOccured() signal is emitted.

        The output location can be relative or empty; in the latter case the
        recorder uses the system specific place and file naming scheme.

        **Access functions:**

        QUrl **outputLocation** () const
        void **setOutputLocation** (const
        QUrl & **location** )
        """
        ...

    def outputLocation(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#outputLocation-prop

        **outputLocation : QUrl**

        This property holds the destination location of media content.

        Setting the location can fail, for example when the service supports
        only local file system locations but a network URL was passed. If the
        operation fails an errorOccured() signal is emitted.

        The output location can be relative or empty; in the latter case the
        recorder uses the system specific place and file naming scheme.

        **Access functions:**

        QUrl **outputLocation** () const
        void **setOutputLocation** (const
        QUrl & **location** )
        """
        ...

    def isAvailable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#isAvailable

        **bool QMediaRecorder::isAvailable() const**

        Returns `true` if media recorder service ready to use.
        """
        ...

    @property
    def actualLocationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#actualLocationChanged

        **[signal] void QMediaRecorder::actualLocationChanged(const QUrl &
        location )**

        Signals that the actual **location** of the recorded media has changed.
        This signal is usually emitted when recording starts.

        **Note:** Notifier signal for property **actualLocation** .
        """
        ...

    @property
    def durationChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#durationChanged

        **[signal] void QMediaRecorder::durationChanged(qint64 duration )**

        Signals that the **duration** of the recorded media has changed.

        **Note:** Notifier signal for property **duration** .
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#errorOccurred

        **[signal] void QMediaRecorder::errorOccurred(QMediaRecorder::Error
        error , const QString & errorString )**

        Signals that an **error** has occurred, with **errorString** containing
        a description of the error.
        """
        ...

    @property
    def mediaFormatChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def metaDataChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#metaDataChanged

        **[signal] void QMediaRecorder::metaDataChanged()**

        Signals that a media object's meta-data has changed.

        If multiple meta-data elements are changed metaDataChanged() is emitted
        once.

        **Note:** Notifier signal for property **metaData** .
        """
        ...

    @property
    def recorderStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qmediarecorder.html#recorderStateChanged

        **[signal] void
        QMediaRecorder::recorderStateChanged(QMediaRecorder::RecorderState state
        )**

        Signals that a media recorder's **state** has changed.

        **Note:** Notifier signal for property **recorderState** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QTransposeProxyModel(QAbstractProxyModel):
    """
    https://doc.qt.io/qt-6/qtransposeproxymodel.html

    **Detailed Description**

    This model will make the rows of the source model become columns of the
    proxy model and vice-versa.

    If the model is a tree, the parents will be transposed as well. For example,
    if an index in the source model had parent `index(2,0)`, it will have parent
    `index(0,2)` in the proxy.
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#QTransposeProxyModel-1

        **QTransposeProxyModel::QTransposeProxyModel(QObject * parent =
        nullptr)**

        Constructs a new proxy model with the given **parent**.
        """
        ...

    def sort(self, column: int, order: Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#sort

        **[override virtual] void QTransposeProxyModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractProxyModel::sort** (int column, Qt::SortOrder
        order).

        This method will perform no action. Use a **QSortFilterProxyModel**  on
        top of this one if you require sorting.
        """
        ...

    def moveColumns(
        self,
        sourceParent: QModelIndex,
        sourceColumn: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#moveColumns

        **[override virtual] bool QTransposeProxyModel::moveColumns(const
        QModelIndex & sourceParent , int sourceRow , int count , const
        QModelIndex & destinationParent , int destinationChild )**

        Reimplements: **QAbstractItemModel::moveColumns** (const QModelIndex
        &sourceParent, int sourceColumn, int count, const QModelIndex
        &destinationParent, int destinationChild).
        """
        ...

    def removeColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#removeColumns

        **[override virtual] bool QTransposeProxyModel::removeColumns(int column
        , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def insertColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#insertColumns

        **[override virtual] bool QTransposeProxyModel::insertColumns(int column
        , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def moveRows(
        self,
        sourceParent: QModelIndex,
        sourceRow: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#moveRows

        **[override virtual] bool QTransposeProxyModel::moveRows(const
        QModelIndex & sourceParent , int sourceRow , int count , const
        QModelIndex & destinationParent , int destinationChild )**

        Reimplements: **QAbstractItemModel::moveRows** (const QModelIndex
        &sourceParent, int sourceRow, int count, const QModelIndex
        &destinationParent, int destinationChild).
        """
        ...

    def removeRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#removeRows

        **[override virtual] bool QTransposeProxyModel::removeRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def insertRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#insertRows

        **[override virtual] bool QTransposeProxyModel::insertRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def index(self, row: int, column: int, parent: QModelIndex = ...) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#index

        **[override virtual] QModelIndex QTransposeProxyModel::index(int row ,
        int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    def parent(self, index: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#parent

        **[override virtual] QModelIndex QTransposeProxyModel::parent(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#mapToSource

        **[override virtual] QModelIndex QTransposeProxyModel::mapToSource(const
        QModelIndex & proxyIndex ) const**

        Reimplements: **QAbstractProxyModel::mapToSource(const QModelIndex
        &proxyIndex) const** .
        """
        ...

    def mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#mapFromSource

        **[override virtual] QModelIndex
        QTransposeProxyModel::mapFromSource(const QModelIndex & sourceIndex )
        const**

        Reimplements: **QAbstractProxyModel::mapFromSource(const QModelIndex
        &sourceIndex) const** .
        """
        ...

    def itemData(self, index: QModelIndex) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#itemData

        **[override virtual] QMap<int, QVariant>
        QTransposeProxyModel::itemData(const QModelIndex & index ) const**

        Reimplements: **QAbstractProxyModel::itemData(const QModelIndex
        &proxyIndex) const** .

        **See also** **setItemData** ().
        """
        ...

    def span(self, index: QModelIndex) -> QSize:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#span

        **[override virtual] QSize QTransposeProxyModel::span(const QModelIndex
        & index ) const**

        Reimplements: **QAbstractProxyModel::span(const QModelIndex &index)
        const** .
        """
        ...

    def setItemData(
        self, index: QModelIndex, roles: typing.Dict[int, typing.Any]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#setItemData

        **[override virtual] bool QTransposeProxyModel::setItemData(const
        QModelIndex & index , const QMap<int, QVariant> & roles )**

        Reimplements: **QAbstractProxyModel::setItemData** (const QModelIndex
        &index, const QMap<int, QVariant> &roles).

        **See also** **itemData** ().
        """
        ...

    def setHeaderData(
        self,
        section: int,
        orientation: Qt.Orientation,
        value: typing.Any,
        role: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#setHeaderData

        **[override virtual] bool QTransposeProxyModel::setHeaderData(int
        section , Qt::Orientation orientation , const QVariant & value , int
        role = Qt::EditRole)**

        Reimplements: **QAbstractProxyModel::setHeaderData** (int section,
        Qt::Orientation orientation, const QVariant &value, int role).

        **See also** **headerData** ().
        """
        ...

    def headerData(
        self, section: int, orientation: Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#headerData

        **[override virtual] QVariant QTransposeProxyModel::headerData(int
        section , Qt::Orientation orientation , int role = Qt::DisplayRole)
        const**

        Reimplements: **QAbstractProxyModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        **See also** **setHeaderData** ().
        """
        ...

    def columnCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#columnCount

        **[override virtual] int QTransposeProxyModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...

    def rowCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#rowCount

        **[override virtual] int QTransposeProxyModel::rowCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def setSourceModel(self, newSourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#setSourceModel

        **[override virtual] void
        QTransposeProxyModel::setSourceModel(QAbstractItemModel * newSourceModel
        )**

        Reimplements: **QAbstractProxyModel::setSourceModel**
        (QAbstractItemModel *sourceModel).
        """
        ...
